@@ -1,14 +1,10 @@
 from __future__ import annotations
 
 import pathlib
-import sys
 from collections import OrderedDict
 from typing import Any, Iterable, MutableMapping
 
-if sys.version_info < (3, 8):
-    from typing_extensions import TypedDict
-else:
-    from typing import TypedDict
+from typing import TypedDict
 
 # Type
 Questions = Iterable[MutableMapping[str, Any]]
@@ -44,6 +40,7 @@ class Settings(TypedDict, total=False):
     allow_abort: bool
     allowed_prefixes: list[str]
     changelog_file: str
+    changelog_format: str | None
     changelog_incremental: bool
     changelog_start_rev: str | None
     changelog_merge_prerelease: bool
@@ -57,6 +54,8 @@ class Settings(TypedDict, total=False):
     prerelease_offset: int
     encoding: str
     always_signoff: bool
+    template: str | None
+    extras: dict[str, Any]
 
 
 name: str = "cz_conventional_commits"
@@ -87,6 +86,7 @@ DEFAULT_SETTINGS: Settings = {
         "squash!",
     ],
     "changelog_file": "CHANGELOG.md",
+    "changelog_format": None,  # default guessed from changelog_file
     "changelog_incremental": False,
     "changelog_start_rev": None,
     "changelog_merge_prerelease": False,
@@ -98,13 +98,17 @@ DEFAULT_SETTINGS: Settings = {
     "prerelease_offset": 0,
     "encoding": encoding,
     "always_signoff": False,
+    "template": None,  # default provided by plugin
+    "extras": {},
 }
 
 MAJOR = "MAJOR"
 MINOR = "MINOR"
 PATCH = "PATCH"
 
-bump_pattern = r"^(((BREAKING[\-\ ]CHANGE|feat|fix|refactor|perf)(\(.+\))?(!)?)|\w+!):"
+CHANGELOG_FORMAT = "markdown"
+
+bump_pattern = r"^((BREAKING[\-\ ]CHANGE|\w+)(\(.+\))?!?):"
 bump_map = OrderedDict(
     (
         (r"^.+!$", MAJOR),
